@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006-2009                                                *
+ *  copyright (C) 2006-2013                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -21,7 +21,7 @@
 class PascalImport : public NativeImportBase
 {
 public:
-    PascalImport(CodeImpThread* thread = 0);
+    explicit PascalImport(CodeImpThread* thread = 0);
     virtual ~PascalImport();
 
 protected:
