@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -46,7 +46,7 @@ public:
         Param
     };
 
-    explicit ActivityWidget( UMLScene * scene, ActivityType activityType = Normal, Uml::IDType id = Uml::id_None );
+    explicit ActivityWidget( UMLScene * scene, ActivityType activityType = Normal, Uml::ID::Type id = Uml::ID::None );
     virtual ~ActivityWidget();
 
     ActivityType activityType() const;
