@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -64,7 +64,7 @@ public:
     static AssociationWidget* create(UMLScene *scene);
     static AssociationWidget* create
                      (UMLScene *scene, UMLWidget* WidgetA,
-                      Uml::AssociationType Type, UMLWidget* WidgetB,
+                      Uml::AssociationType::Enum assocType, UMLWidget* WidgetB,
                       UMLObject *umlobject = NULL);
 
     virtual ~AssociationWidget();
@@ -94,7 +94,7 @@ public:
 
     virtual void constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY,
                                   UMLSceneValue textWidth, UMLSceneValue textHeight,
-                                  Uml::TextRole tr);
+                                  Uml::TextRole::Enum tr);
 
     virtual void calculateNameTextSegment();
 
@@ -107,42 +107,42 @@ public:
     bool operator==(const AssociationWidget & Other) const;
     bool operator!=(AssociationWidget & Other) const;
 
-    FloatingTextWidget* textWidgetByRole(Uml::TextRole tr) const;
+    FloatingTextWidget* textWidgetByRole(Uml::TextRole::Enum tr) const;
 
     FloatingTextWidget* nameWidget() const;
     QString name() const;
     void setName(const QString &strRole);
 
-    FloatingTextWidget* roleWidget(Uml::Role_Type role) const;
-    QString roleName(Uml::Role_Type role) const;
-    void setRoleName(const QString &strRole, Uml::Role_Type role);
+    FloatingTextWidget* roleWidget(Uml::RoleType::Enum role) const;
+    QString roleName(Uml::RoleType::Enum role) const;
+    void setRoleName(const QString &strRole, Uml::RoleType::Enum role);
 
-    QString roleDocumentation(Uml::Role_Type role) const;
-    void setRoleDocumentation(const QString& doc, Uml::Role_Type role);
+    QString roleDocumentation(Uml::RoleType::Enum role) const;
+    void setRoleDocumentation(const QString& doc, Uml::RoleType::Enum role);
 
-    FloatingTextWidget* multiplicityWidget(Uml::Role_Type role) const;
-    QString multiplicity(Uml::Role_Type role) const;
-    void setMultiplicity(const QString& text, Uml::Role_Type role);
+    FloatingTextWidget* multiplicityWidget(Uml::RoleType::Enum role) const;
+    QString multiplicity(Uml::RoleType::Enum role) const;
+    void setMultiplicity(const QString& text, Uml::RoleType::Enum role);
 
-    Uml::Visibility visibility(Uml::Role_Type role) const;
-    void setVisibility(Uml::Visibility value, Uml::Role_Type role);
+    Uml::Visibility::Enum visibility(Uml::RoleType::Enum role) const;
+    void setVisibility(Uml::Visibility::Enum value, Uml::RoleType::Enum role);
 
-    FloatingTextWidget* changeabilityWidget(Uml::Role_Type role) const;
-    Uml::Changeability changeability(Uml::Role_Type role) const;
-    void setChangeability(Uml::Changeability value, Uml::Role_Type role);
+    FloatingTextWidget* changeabilityWidget(Uml::RoleType::Enum role) const;
+    Uml::Changeability::Enum changeability(Uml::RoleType::Enum role) const;
+    void setChangeability(Uml::Changeability::Enum value, Uml::RoleType::Enum role);
 
-    Uml::IDType widgetIDForRole(Uml::Role_Type role) const;
-    UMLWidget* widgetForRole(Uml::Role_Type role) const;
-    void setWidgetForRole(UMLWidget* widget, Uml::Role_Type role);
+    Uml::ID::Type widgetIDForRole(Uml::RoleType::Enum role) const;
+    UMLWidget* widgetForRole(Uml::RoleType::Enum role) const;
+    void setWidgetForRole(UMLWidget* widget, Uml::RoleType::Enum role);
 
-    bool setWidgets(UMLWidget* widgetA, Uml::AssociationType assocType, UMLWidget* widgetB);
+    bool setWidgets(UMLWidget* widgetA, Uml::AssociationType::Enum assocType, UMLWidget* widgetB);
 
     bool checkAssoc(UMLWidget *widgetA, UMLWidget *widgetB);
 
     bool hasWidget(UMLWidget* widget);
 
-    Uml::AssociationType associationType() const;
-    void setAssociationType(Uml::AssociationType type);
+    Uml::AssociationType::Enum associationType() const;
+    void setAssociationType(Uml::AssociationType::Enum type);
 
     bool isCollaboration() const;
 
@@ -188,8 +188,8 @@ public:
     virtual void setLineColor(const QColor &color);
     void setLineWidth(uint width);
 
-    void setIndex(int index, Uml::Role_Type role);
-    int getIndex(Uml::Role_Type role) const;
+    void setIndex(int index, Uml::RoleType::Enum role);
+    int getIndex(Uml::RoleType::Enum role) const;
 
     void calculateEndingPoints();
 
@@ -220,10 +220,10 @@ protected:
 private:
     void init();
 
-    UMLScenePoint calculateTextPosition(Uml::TextRole role);
-    void setTextPosition(Uml::TextRole role);
-    void setTextPositionRelatively(Uml::TextRole role, const UMLScenePoint &oldPosition);
-    void setFloatingText(Uml::TextRole role, const QString& text, FloatingTextWidget* &ft);
+    UMLScenePoint calculateTextPosition(Uml::TextRole::Enum role);
+    void setTextPosition(Uml::TextRole::Enum role);
+    void setTextPositionRelatively(Uml::TextRole::Enum role, const UMLScenePoint &oldPosition);
+    void setFloatingText(Uml::TextRole::Enum role, const QString& text, FloatingTextWidget* &ft);
 
     /**
      * Constructor is made non accessible:
@@ -241,7 +241,7 @@ private:
 
     void moveEvent(QMoveEvent *me);
 
-    Uml::TextRole calculateNameType(Uml::TextRole defaultRoleType);
+    Uml::TextRole::Enum calculateNameType(Uml::TextRole::Enum defaultRoleType);
 
 //    bool isPointInsideBoundaries(int PosX, int PosY, UMLScenePoint & SPoint,
 //                                 uint & StartSegmentIndex, uint & EndSegmentIndex);
@@ -273,28 +273,28 @@ private:
         UMLWidget* umlWidget;    ///< UMLWidget at this role's side of this association
 
         UMLScenePoint m_OldCorner;      ///< old top left corner before moving
-        Region m_WidgetRegion;   ///< region of this role's widget
+        Region        m_WidgetRegion;   ///< region of this role's widget
 
         int m_nIndex;        ///< the index of where the line is on the region for this role
         int m_nTotalCount;   ///< total amount of associations on the region this role's line is on
 
         // The following items are only used if m_pObject is not set.
-        Uml::Visibility      visibility;
-        Uml::Changeability   changeability;
-        QString              roleDocumentation;
+        Uml::Visibility::Enum     visibility;
+        Uml::Changeability::Enum  changeability;
+        QString                   roleDocumentation;
 
     };
 
     void updateRegionLineCount(int index, int totalCount,
-                               AssociationWidget::Region region, Uml::Role_Type role);
+                               AssociationWidget::Region region, Uml::RoleType::Enum role);
 
-    void updateAssociations(int totalCount, Region region, Uml::Role_Type role);
+    void updateAssociations(int totalCount, Region region, Uml::RoleType::Enum role);
 
-    int getRegionCount(Region region, Uml::Role_Type role);
+    int getRegionCount(Region region, Uml::RoleType::Enum role);
 
-    void doUpdates(int otherX, int otherY, Uml::Role_Type role);
+    void doUpdates(int otherX, int otherY, Uml::RoleType::Enum role);
 
-    void setChangeWidget(const QString &strChangeWidget, Uml::Role_Type role);
+    void setChangeWidget(const QString &strChangeWidget, Uml::RoleType::Enum role);
 
     void checkPoints(const UMLScenePoint &p);
 
@@ -337,7 +337,7 @@ private:
 
     AssociationLine *m_associationLine;      ///< the definition points for the association line
     ClassifierWidget *m_associationClass;    ///< used if we have an assoc. class
-    Uml::AssociationType m_associationType;  ///< is only used if m_pObject is not set
+    Uml::AssociationType::Enum m_associationType;  ///< is only used if m_pObject is not set
     WidgetRole  m_role[2];
     FloatingTextWidget* m_nameWidget;  ///< displays the name of this association
 
